# Simulation of Neumann-Kipping (2009)

## Description

Vertical pipe flow cases with two different types of flow constrictions are
setup in OpenFOAM using the baseline model set developed at HZDR. The model
set is validated with the experimental data of Neumann-Kipping et al. [^1].
The cases selected here are 072 and 074.

## Technical Information

The cases contain the experimental data for validation in the validation folder.
By executing the Allrun script inside the case folder the simulations are run
and plots generated comparing the computed results to the experimental data.

## Pre-Processing

The length of the computed pipe geometry was shortened to xxm in order
to achieve fully-developed flow conditions at the first measurement level
while optimizing computational costs.

The cases with a ring-shaped flow constriction are modelled using a
two-dimensional axissymmetric computational domain.

The cases with the semi-circular flow constriction are modelled using a
three-dimensional domain of half the pipe crosssection.

For all cases the gas is injected with a zero-velocity difference inlet
with the bubble size distribution measured at Level A1.

## Post-Processing

Radial plots of the gas void fraction are generated for Level F2.
Auxiliary plots are the crosssectional-averaged axial plots of the gas void
fraction and velocity, as well as the bubble size distribution at Level F2.

### Data Validation

|   Field   | Validation | Reference |
|:---------:|:----------:|:---------:|
| alpha.air | alpha.dat  | line.csv  |

## Keywords

pipe, circular-cross-section, variable-cross-section, bottom-injection,
vertical-upward, co-current, air-water, bubbly-flow, variable-bubble-size,
polydisperse, incompressible, filtered-water, steady-state, developing,
isothermal, two-phase-inlet, pressure-outlet

ring*: 2D-wedge

baffle*: 3D, one-gas

ring_072: one-gas

ring_074: multiple-gas

## Additional Remarks

* case ring_072 crashes with multiple velocity groups due to very high
  coalescence rates and the lift coefficient reaching extreme values using
  the Hessenkemper correlation
* baffle cases were only computed with one velocity group for computational
  time reasons

## Literature

[^1]: Neumann-Kipping, M. and Bieberle, A. and Hampel, U. 2020. Investigations
      on bubbly two-phase flow in a constricted vertical pipe. International
      Journal of Multiphase Flow, 130, 103340.
